@@ -25,3 +25,7 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c('brazil_2010',
                                                         'code_region',
                                                         'name_region',
                                                         'group_by'))
+
+.onLoad <- function(lib, pkg) {
+  requireNamespace("sf")
+}
